@@ -45,16 +45,16 @@ class Calculator:
         # TODO: Pick a method to get RAM accurately (pt.get_ram() seems to get RAM wrong on Blake)
         a_size = a_len * a_width * double_size
         # output.screen("'a' takes up ", 100 * a_size / pt.get_ram(), "% of the total memory")
-        output.screen("'a' takes up ", 100 * a_size / config.sections["MEMORY"].memory,
-                      "% of the total memory", config.sections["MEMORY"].memory*1e-9, "GB of RAM")
+        output.screen(">>> Matrix of descriptors takes up ", "{:.4f}".format(100 * a_size / config.sections["MEMORY"].memory),
+                      "% of the total memory:", "{:.4f}".format(config.sections["MEMORY"].memory*1e-9), "GB")
         if a_size / pt.get_ram() > 0.5 and not config.sections["MEMORY"].override:
-            raise MemoryError("The 'a' matrix is larger than 50% of your RAM. \n Aborting...!")
+            raise MemoryError("The descriptor matrix is larger than 50% of your RAM. \n Aborting...!")
         elif a_size / pt.get_ram() > 0.5 and config.sections["MEMORY"].override:
             output.screen("Warning: I hope you know what you are doing!")
 
-        pt.create_shared_array('a', a_len, a_width)
-        pt.create_shared_array('b', a_len)
-        pt.create_shared_array('w', a_len)
+        pt.create_shared_array('a', a_len, a_width, tm=config.sections["SOLVER"].true_multinode)
+        pt.create_shared_array('b', a_len, tm=config.sections["SOLVER"].true_multinode)
+        pt.create_shared_array('w', a_len, tm=config.sections["SOLVER"].true_multinode)
         pt.slice_array('a')
 
     def process_configs(self, data, i):
