@@ -4,8 +4,6 @@ from ..parallel_tools import pt
 from ..io.input import config
 import numpy as np
 
-# TODO: Ask about onehot_fraction for energy
-
 
 class LammpsSnap(Calculator):
 
@@ -69,7 +67,20 @@ class LammpsSnap(Calculator):
         if config.sections["REFERENCE"].atom_style == "charge":
             self._create_charge()
 
-        self._set_variables(**_lammps_variables(config.sections["BISPECTRUM"].__dict__))
+        # this is super clean when there is only one value per key, needs reworking
+#        self._set_variables(**_lammps_variables(config.sections["BISPECTRUM"].__dict__))
+
+        #Needs reworking when lammps will accept variable 2J
+        self._lmp.command(f"variable twojmax equal {max(config.sections['BISPECTRUM'].twojmax)}")
+        self._lmp.command(f"variable rcutfac equal {config.sections['BISPECTRUM'].rcutfac}")
+        self._lmp.command(f"variable rfac0 equal {config.sections['BISPECTRUM'].rfac0}")
+#        self._lmp.command(f"variable rmin0 equal {config.sections['BISPECTRUM'].rmin0}")
+
+        for i,j in enumerate(config.sections["BISPECTRUM"].wj):
+            self._lmp.command(f"variable wj{i+1} equal {j}")
+
+        for i,j in enumerate(config.sections["BISPECTRUM"].radelem):
+            self._lmp.command(f"variable radelem{i+1} equal {j}")
 
         for line in config.sections["REFERENCE"].lmp_pairdecl:
             self._lmp.command(line.lower())
@@ -108,7 +119,7 @@ class LammpsSnap(Calculator):
 
     def _create_charge(self):
         for i, q in enumerate(self._data["Charges"]):
-            self._lmp.command(f"set atom {i + 1} charge {q:20.20g} ")
+            self._lmp.command(f"set atom {i + 1} charge {q[0]:20.20g} ")
         n_atoms = int(self._lmp.get_natoms())
         assert i + 1 == n_atoms, f"Atom counts don't match when assigning charge: {i + 1}, {n_atoms}"
 
@@ -174,12 +185,13 @@ class LammpsSnap(Calculator):
         ndim_virial = 6
         nrows_virial = ndim_virial
         nrows_snap = nrows_energy + nrows_force + nrows_virial
-        ncols_bispectrum = num_types * n_coeff
+        ncols_bispectrum = n_coeff * num_types
         ncols_reference = 1
         ncols_snap = ncols_bispectrum + ncols_reference
         index = pt.fitsnap_dict['a_indices'][self._i]
 
         lmp_snap = _extract_compute_np(self._lmp, "snap", 0, 2, (nrows_snap, ncols_snap))
+
         if (np.isinf(lmp_snap)).any() or (np.isnan(lmp_snap)).any():
             raise ValueError('Nan in computed data of file {} in group {}'.format(self._data["File"],
                                                                                   self._data["Group"]))
@@ -188,6 +200,23 @@ class LammpsSnap(Calculator):
         icolref = ncols_bispectrum
         if config.sections["CALCULATOR"].energy:
             b_sum_temp = lmp_snap[irow, :ncols_bispectrum] / num_atoms
+
+            # Check for no neighbors using B[0,0,0] components
+            # these strictly increase with total neighbor count
+            # minimum value depends on SNAP variant
+
+            EPS = 1.0e-10
+            b000sum0 = 0.0
+            nstride = n_coeff
+            if not config.sections["BISPECTRUM"].bzeroflag: b000sum0 = 1.0
+            if config.sections["BISPECTRUM"].chemflag:
+                nstride //= num_types*num_types*num_types
+                if config.sections["BISPECTRUM"].wselfallflag:
+                    b000sum0 *= num_types*num_types*num_types
+            b000sum = sum(b_sum_temp[::nstride])
+            if (abs(b000sum - b000sum0) < EPS): 
+                print("WARNING: Configuration has no SNAP neighbors")
+
             if not config.sections["BISPECTRUM"].bzeroflag:
                 b_sum_temp.shape = (num_types, n_coeff)
                 onehot_atoms = np.zeros((num_types, 1))
@@ -196,7 +225,8 @@ class LammpsSnap(Calculator):
                 onehot_atoms /= len(self._data["AtomTypes"])
                 b_sum_temp = np.concatenate((onehot_atoms, b_sum_temp), axis=1)
                 b_sum_temp.shape = (num_types * n_coeff + num_types)
-            pt.shared_arrays['a'].array[index] = b_sum_temp
+
+            pt.shared_arrays['a'].array[index] = b_sum_temp * config.sections["BISPECTRUM"].blank2J
             ref_energy = lmp_snap[irow, icolref]
             pt.shared_arrays['b'].array[index] = (energy - ref_energy) / num_atoms
             pt.shared_arrays['w'].array[index] = self._data["eweight"]
@@ -211,7 +241,8 @@ class LammpsSnap(Calculator):
                 onehot_atoms = np.zeros((np.shape(db_atom_temp)[0], num_types, 1))
                 db_atom_temp = np.concatenate([onehot_atoms, db_atom_temp], axis=2)
                 db_atom_temp.shape = (np.shape(db_atom_temp)[0], num_types * n_coeff + num_types)
-            pt.shared_arrays['a'].array[index:index+num_atoms * ndim_force] = db_atom_temp
+            pt.shared_arrays['a'].array[index:index+num_atoms * ndim_force] = \
+                np.matmul(db_atom_temp, np.diag(config.sections["BISPECTRUM"].blank2J))
             ref_forces = lmp_snap[irow:irow + nrows_force, icolref]
             pt.shared_arrays['b'].array[index:index+num_atoms * ndim_force] = \
                 self._data["Forces"].ravel() - ref_forces
@@ -228,7 +259,8 @@ class LammpsSnap(Calculator):
                 onehot_atoms = np.zeros((np.shape(vb_sum_temp)[0], num_types, 1))
                 vb_sum_temp = np.concatenate([onehot_atoms, vb_sum_temp], axis=2)
                 vb_sum_temp.shape = (np.shape(vb_sum_temp)[0], num_types * n_coeff + num_types)
-            pt.shared_arrays['a'].array[index:index+ndim_virial] = vb_sum_temp
+            pt.shared_arrays['a'].array[index:index+ndim_virial] = \
+                np.matmul(vb_sum_temp, np.diag(config.sections["BISPECTRUM"].blank2J))
             ref_stress = lmp_snap[irow:irow + nrows_virial, icolref]
             pt.shared_arrays['b'].array[index:index+ndim_virial] = \
                 self._data["Stress"][[0, 1, 2, 1, 0, 0], [0, 1, 2, 2, 2, 1]].ravel() - ref_stress
@@ -236,7 +268,7 @@ class LammpsSnap(Calculator):
                 self._data["vweight"]
             index += ndim_virial
 
-
+# this is super clean when there is only one value per key, needs reworking
 def _lammps_variables(bispec_options):
     d = {k: bispec_options[k] for k in
          ["rcutfac",
