@@ -2,7 +2,7 @@
 from .sections import Section, output
 from pandas import read_csv
 from os import path
-
+from ...parallel_tools import pt
 
 def _str_2_fun(some_list):
     for i, item in enumerate(some_list):
@@ -20,9 +20,15 @@ class Groups(Section):
 
     def __init__(self, name, config, args):
         super().__init__(name, config, args)
+        allowedkeys = ['group_sections','group_types','smartweights','random_sampling','BOLTZ']
+        for value_name in config['GROUPS']:
+            if value_name in allowedkeys: continue
+#            else: pt.single_print(">>> Found unmatched variable in GROUPS section of input: ",value_name)
+
         self.group_sections = self.get_value("GROUPS", "group_sections", "name size eweight fweight vweight").split()
         self.group_types = self.get_value("GROUPS", "group_types", "str float float float float").split()
         self.smartweights = self.get_value("GROUPS", "smartweights", "0", "bool")
+        self.random_sampling = self.get_value("GROUPS", "random_sampling", "0", "bool")
         self.boltz = self.get_value("BISPECTRUM", "BOLTZ", "0", "float")
         _str_2_fun(self.group_types)
         self.group_table = None
