@@ -1,10 +1,17 @@
 from .sections import Section, output
-
+from ...parallel_tools import pt
 
 class Scraper(Section):
 
     def __init__(self, name, config, args):
         super().__init__(name, config, args)
+        allowedkeys = ['scraper','save_group_scrape','read_group_scrape','property_array']
+        for value_name in config['SCRAPER']:
+            if value_name in allowedkeys: continue
+            else:
+                raise RuntimeError(">>> Found unmatched variable in SCRAPER section of input: ", value_name)
+                #pt.single_print(">>> Found unmatched variable in SCRAPER section of input: ",value_name)
+
         self.scraper = self.get_value("SCRAPER", "scraper", "JSON")
         self.save_group_scrape = self.get_value("SCRAPER", "save_group_scrape", "None", "str")
         self.read_group_scrape = self.get_value("SCRAPER", "read_group_scrape", "None", "str")
