@@ -1,9 +1,11 @@
-from fitsnap3.parallel_tools import pt, output
+from ...parallel_tools import pt, output
 from distutils.util import strtobool
+from os import getcwd
 
 
 class Section:
     parameters = []
+    relative_directory = None
 
     def __init__(self, name, config, args):
         self.name = name
@@ -52,3 +54,18 @@ class Section:
     @classmethod
     def add_parameter(cls, section, key, fallback, interpreter):
         cls.parameters.append([section, key, fallback, interpreter])
+
+    @classmethod
+    def _get_relative_directory(cls, self):
+        if cls.relative_directory is None:
+            cls._set_relative_directory(self)
+        return cls.relative_directory
+
+    @classmethod
+    def _set_relative_directory(cls, self):
+        paths = getcwd().split('/') + self._args.infile.split('/')[:-1]
+        relative_directory = ''
+        for directory in paths[:-1]:
+            relative_directory += directory + '/'
+        relative_directory += paths[-1]
+        cls.relative_directory = relative_directory
