@@ -1,5 +1,5 @@
 """Template Class"""
-from fitsnap3.io.sections.sections import Section
+from .sections import Section
 
 
 class Default(Section):
